California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 93 - LIMITS ON LEGISLATORS' TERMS IN OFFICE. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1299457 | YES ON 93, CITIZENS FOR ACCOUNTABILITY AND LEGISLATIVE REFORM | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1302904 | MONTEREY BAY & SOUTH BAY COMMITTEE FOR YES ON PROPOSITION 93 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1296108 | YES ON PROP. 93, A COALITION OF BUSINESS, LABOR, TEACHERS, LAWMAKERS, PUBLIC SAFETY AND ASSEMBLYMEMBERS DE LEON, NUNEZ, BASS AND LIEU | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1297987 | NO ON 93 CALIFORNIA TERM LIMITS DEFENSE FUND SPONSORED AND MAJOR FUNDING BY US TERM LIMITS INC. WITH HELP FROM ADVOCATES OF TERM LIMITS. | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1302319 | ALLIANCE FOR CALIFORNIA'S RENEWAL | OPPOSE